==> Bio_Epidemiology_NER-0.0.1.tar.gz: Bio_Epidemiology_NER-0.0.1/README.md <==
Bio_Epidemiology_NER is an Python library built on top of biomedical-ner-all model to recognize bio-medical entities from a corpus or a medical report

| Feature  | Output  |
|---|---|
| Named Entity Recognition | Recognize 84 bio-medical entities |
| PDF Support | feature coming soon...|


## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install Bio_Epidemiology_NER

```bash
pip install Bio_Epidemiology_NER
```

## Usage

### NER with Bio_Epidemiology_NER
```python
# load all the functions
from Bio_Epidemiology_NER.bio_recognizer import ner_prediction

# returns the predicted class along with the probability of the actual EnvBert model
doc = """
	CASE: A 28-year-old previously healthy man presented with a 6-week history of palpitations. 
      The symptoms occurred during rest, 2–3 times per week, lasted up to 30 minutes at a time 
      and were associated with dyspnea. Except for a grade 2/6 holosystolic tricuspid regurgitation 
      murmur (best heard at the left sternal border with inspiratory accentuation), physical 
      examination yielded unremarkable findings.
      """

# returns a dataframe output
ner_prediction(corpus=text, compute='gpu') #pass compute='cpu' if using cpu

```


## About
This model is part of the Research topic "AI in Biomedical field" conducted by Deepak John Reji, Shaina Raza. If you use this work (code, model or dataset),

Please cite us and star at: https://github.com/dreji18/biomedicalNER

## License
[MIT](https://choosealicense.com/licenses/mit/) License

==> Bio_Epidemiology_NER-0.0.2.tar.gz: Bio_Epidemiology_NER-0.0.2/README.md <==
Bio-Epidemiology-NER is an Python library built on top of biomedical-ner-all model to recognize bio-medical entities from a corpus or a medical report

| Feature  | Output  |
|---|---|
| Named Entity Recognition | Recognize 84 bio-medical entities |
| PDF Support | feature coming soon...|


## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install Bio-Epidemiology-NER

```bash
pip install Bio-Epidemiology-NER
```

## Usage

### NER with Bio_Epidemiology_NER
```python
# load all the functions
from Bio_Epidemiology_NER.bio_recognizer import ner_prediction

# returns the predicted class along with the probability of the actual EnvBert model
doc = """
	CASE: A 28-year-old previously healthy man presented with a 6-week history of palpitations. 
      The symptoms occurred during rest, 2–3 times per week, lasted up to 30 minutes at a time 
      and were associated with dyspnea. Except for a grade 2/6 holosystolic tricuspid regurgitation 
      murmur (best heard at the left sternal border with inspiratory accentuation), physical 
      examination yielded unremarkable findings.
      """

# returns a dataframe output
ner_prediction(corpus=doc, compute='gpu') #pass compute='cpu' if using cpu

```


## About
This model is part of the Research topic "AI in Biomedical field" conducted by Deepak John Reji, Shaina Raza. If you use this work (code, model or dataset),

Please cite us and star at: https://github.com/dreji18/biomedicalNER

## License
[MIT](https://choosealicense.com/licenses/mit/) License
